UncertainPrediction
===================

.. currentmodule:: pykeen.models.uncertainty

.. autoclass:: UncertainPrediction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~UncertainPrediction.score
      ~UncertainPrediction.uncertainty

   .. rubric:: Methods Summary

   .. autosummary::

      ~UncertainPrediction.from_scores

   .. rubric:: Attributes Documentation

   .. autoattribute:: score
   .. autoattribute:: uncertainty

   .. rubric:: Methods Documentation

   .. automethod:: from_scores
